… | OiRA

Help

1. Příprava
2. Zapojení
3. Vyhledání rizik + Hodnocení rizik
   1. 1 Commercial manned guarding
   2. Ω Rizika přidaná uživatelem
      1. Ω.1 The entrance floor is often wet
      2. Ω.2 …
   - Nezodpovězeno
   - Odloženo
   - OK
   - Pozornost
4. Akční plán
5. Zpráva
6. Status 0%

## Popište riziko…

Ne, jsou vyžadována další opatření. Ano, zbývající riziko je přijatelné.

Select the priority of this risk Low Medium High
Informace
Vložit obrázeklabel_upload_image
Poznámky

Scroll to top
Back

## add-risk.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More